About Weblate
=============

Project goals
-------------

Web based translation tool with tight git integration supporting a wide range
of file formats, making it easy for translators to contribute.

The translations should be kept within the same repository as the source code and
the translation process should closely follow development.

There is no plan regarding heavy conflict resolution as these should be primarily
handled by git.

Project name
------------

The project is named as mixture of the words web and translate.

Project website
---------------

You can find the project website at <https://weblate.org/>, there is also
a demonstration server at <https://demo.weblate.org/>. This documentation
can be browsed on <https://docs.weblate.org/>.

Authors
-------

This tool was written by Michal Čihař <michal@cihar.com>.
